@@ -1,8 +1,9 @@
 use nu_engine::EvaluationContext;
+use nu_errors::ShellError;
 use std::error::Error;
 
 #[allow(unused_imports)]
-use crate::prelude::*;
+use std::sync::atomic::Ordering;
 
 #[allow(unused_imports)]
 use nu_engine::script::LineResult;
@@ -31,7 +32,7 @@ pub fn convert_rustyline_result_to_string(input: Result<String, ReadlineError>)
         Err(ReadlineError::Interrupted) => LineResult::CtrlC,
         Err(ReadlineError::Eof) => LineResult::CtrlD,
         Err(err) => {
-            outln!("Error: {:?}", err);
+            eprintln!("Error: {:?}", err);
             LineResult::Break
         }
     }
@@ -258,14 +259,14 @@ pub fn rustyline_hinter(
 pub fn configure_ctrl_c(_context: &EvaluationContext) -> Result<(), Box<dyn Error>> {
     #[cfg(feature = "ctrlc")]
     {
-        let cc = _context.ctrl_c.clone();
+        let cc = _context.ctrl_c().clone();
 
         ctrlc::set_handler(move || {
             cc.store(true, Ordering::SeqCst);
         })?;
 
-        if _context.ctrl_c.load(Ordering::SeqCst) {
-            _context.ctrl_c.store(false, Ordering::SeqCst);
+        if _context.ctrl_c().load(Ordering::SeqCst) {
+            _context.ctrl_c().store(false, Ordering::SeqCst);
         }
     }
 
